package VMOMI::HostInternetScsiHbaIscsiIpv6AddressAddressConfigurationType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
